#include <Xm/Xm.h>	    /* Motif includes */
#include <Xm/PushB.h>
#include <Xm/RowColumn.h>

#include "Video.h"

void UserInterface::init(Video *v)
  {
     XmString label;

     /*
      * Motif interface initialization
      */
     
     /* Application */
     toplevel = XtVaAppInitialize(&app, "Video plugin", NULL, 0, 
				&argc, argv, NULL,	   
				  NULL);
     
     /* Horizontal rowcolumn widget (for buttons) */
     rowcol =  XtVaCreateWidget("rowcol", xmRowColumnWidgetClass, 
				toplevel,
				XmNorientation, XmHORIZONTAL,
				NULL);
     /* Start button */  
     label = XmStringCreateSimple("START");
     start_but = XtVaCreateManagedWidget("start", xmPushButtonWidgetClass, 
					 rowcol,
					 XmNwidth, 100,
					 XmNalignment, XmALIGNMENT_CENTER,
					 XmNlabelString, label,
					 NULL);
     XmStringFree(label);
     
     /* Stop button */
     label = XmStringCreateSimple("STOP");
     stop_but = XtVaCreateManagedWidget("stop", xmPushButtonWidgetClass, 
					rowcol,
					XmNlabelString, label,
					NULL);
     XmStringFree(label);
     
     /* Buttons callbacks setting */
     XtAddCallback(start_but, XmNactivateCallback, start_pushed, NULL);
     XtAddCallback(stop_but, XmNactivateCallback, stop_pushed, NULL);
     
     XtManageChild(rowcol);

     XtRealizeWidget(toplevel);
     
     /* Current state init */
     current_state = STOP_STATE;
     
     /* Graphic window init */
     xsize = 176;
     ysize = 144;

     foreground();

     prefsize(xsize,ysize);
     win = winopen("Simpleccapt Window");
     RGBmode();
     pixmode(PM_TTOB, 1);
     gconfig();

     video = v;
  }

void UserInterface::put_frame(void *frame)
  {
     /* Write the data to the screen */
     lrectwrite(0,0, xsize-1, ysize-1, frame);
  }

void UserInterface::start_pushed()
  {
     if (current_state == STOP_STATE)
       {
	  current_state = PLAY_STATE;
	  workproc = XtAppAddWorkProc(app, send_video, NULL);
       }
  }

void UserInterface::stop_pushed()
  {
     if (current_state == PLAY_STATE)
       {
	  current_state = STOP_STATE;
	  XtRemoveWorkProc(workproc);
       }
  }

void UserInterface::send_video()
  {
     static int rate = 0;
     char *dataPtr;

     dataPtr = video->capture_frame();
	  
     if(rate == 0)
       {
	  SendFrame(dataPtr);
       }

     video->release_frame();
     
     rate = (rate + 1) % 5;

     if(current_state == PLAY_STATE)
	workproc = XtAppAddWorkProc(app, send_video, NULL);

  }
